(document:surround "/std/frame")

(define *name* (global 'name))

;;; UI

width 600
height 500

(hbox align "left"
	  (label text (bold (_ "VLAN Configuration for Interface ")))(label name "iface_label"))
(label name "iface" visibility #t)
(button (_ "Back") name "back")

(separator)
(gridbox
  columns "60;40"
(listbox name "vlans_list" max-width 155)
  ;;
(gridbox
  columns "0;100"
          (label text (_ "VID (1-4095):"))
          (edit name "vlan_vid")
		  (spacer)
  (hbox align "right"
	  (button (_ "Add VLAN") name "add_vlan")
      (button (_ "Remove") name "remove_vlan"))
          ))

;;; Functions

(define (ui-read-iface name)
  (catch/message
	(lambda()
	  (form-update-enum "vlans_list" (woo-list "/net-vlan/iface_vlans"
											   'iface name
											   'language (form-value "language"))))))

(define (vlan-read)
  (let ((name (form-value "vlans_list")))
	(catch/message
	  (lambda()
		(form-update-value-list '("vlan_vid") (woo-read-first "/net-vlan"
															  'vlan_name name
															  'language (form-value "language"))))))
  (ui-update-activity))

(define (vlan-add)
  (catch/message
	(lambda()
	  (let* ((iface (form-value "iface"))
			 (vlan_name (woo-get-option
						  (woo-read-first "/net-vlan/new_vlan"
										  'iface iface
										  'vid (form-value "vlan_vid")
										  'language (form-value "language"))
						  'new_vlan)))
		(ui-read-iface iface)
		(form-update-value "vlans_list" vlan_name))))
  (ui-update-activity)
  (vlan-read))

(define (vlan-remove)
  (catch/message
	(lambda()
	  (woo-write "/net-vlan/rm_vlan" 'vlan_name (form-value "vlans_list") 'language (form-value "language"))))
  (ui-read-iface (form-value "iface"))
  (form-update-value "vlan_vid" "")
  (ui-update-activity))

(define (ui-update-activity)
  (let* ((n (form-value "vlans_list"))
		 (a (and (string? n)
				 (not (empty-string? n)))))
	(form-update-activity "remove_vlan" a)))

(define (ui-init name)
  (form-update-value "iface" name)
  (ui-read-iface name)
  (ui-update-activity))

(define (ui-exit)
  (document:end))

;;
(document:root
  (when loaded
  (ui-init *name*)
  (form-bind "back" "click" ui-exit)
  (form-bind "vlans_list"  "change" vlan-read)
  (form-bind "add_vlan" "click" vlan-add)
  (form-bind "remove_vlan" "click" vlan-remove)))
